@@ -1,5 +1,5 @@
 # Verilog - Verilog Perl Interface
-# $Id: Netlist.pm 30571 2007-01-23 18:43:04Z wsnyder $
+# $Id: Netlist.pm 32863 2007-02-28 14:14:18Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -25,7 +25,7 @@ use Verilog::Netlist::Subclass;
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '2.371';
+$VERSION = '2.372';
 
 ######################################################################
 #### Error Handling
@@ -44,6 +44,7 @@ sub new {
 		options => undef,	# Usually pointer to Verilog::Getopt
 		implicit_wires_ok => 1,
 		link_read => 1,
+		#include_open_nonfatal => 0,
 		#keep_comments => 0,
 		_libraries_done => {},
 		@_};
@@ -368,6 +369,9 @@ Creates a new netlist structure.  Pass optional parameters by name.  The
 parameter "options" may contain a reference to a Verilog::Getopt module,
 to be used for locating files.
 
+The parameter "include_open_nonfatal=>1" is passed to Verilog::Preproc
+to ignore any include files that do not exist.
+
 =item $netlist->dump
 
 Prints debugging information for the entire netlist structure.
